@@ -692,3 +692,53 @@ class TestStore(base.StoreBaseTest,
         self.assertEqual(self.called_commands_expected,
                          self.called_commands_actual)
         super(TestStore, self).tearDown()
+
+    def test_create_image_in_native_thread(self):
+        # Tests that we use non-0 features from ceph.conf and cast to int.
+        fsid = 'fake'
+        features = '3'
+        conf_get_mock = mock.Mock(return_value=features)
+        conn = mock.Mock(conf_get=conf_get_mock)
+        ioctxt = mock.sentinel.ioctxt
+        name = '1'
+        size = 1024
+        order = 3
+        fake_proxy = mock.MagicMock()
+        fake_rbd = mock.MagicMock()
+
+        with mock.patch.object(rbd_store.tpool, 'Proxy') as tpool_mock, \
+                mock.patch.object(rbd_store.rbd, 'RBD') as rbd_mock:
+            tpool_mock.return_value = fake_proxy
+            rbd_mock.return_value = fake_rbd
+            location = self.store._create_image(
+                fsid, conn, ioctxt, name, size, order)
+            self.assertEqual(fsid, location.specs['fsid'])
+            self.assertEqual(rbd_store.DEFAULT_POOL, location.specs['pool'])
+            self.assertEqual(name, location.specs['image'])
+            self.assertEqual(rbd_store.DEFAULT_SNAPNAME,
+                             location.specs['snapshot'])
+
+        tpool_mock.assert_called_once_with(fake_rbd)
+        fake_proxy.create.assert_called_once_with(ioctxt, name, size, order,
+                                                  old_format=False, features=3)
+
+    def test_delete_image_in_native_thread(self):
+        fake_proxy = mock.MagicMock()
+        fake_rbd = mock.MagicMock()
+        fake_ioctx = mock.MagicMock()
+
+        with mock.patch.object(rbd_store.tpool, 'Proxy') as tpool_mock, \
+                mock.patch.object(rbd_store.rbd, 'RBD') as rbd_mock, \
+                mock.patch.object(self.store, 'get_connection') as mock_conn:
+
+            mock_get_conn = mock_conn.return_value.__enter__.return_value
+            mock_ioctx = mock_get_conn.open_ioctx.return_value.__enter__
+            mock_ioctx.return_value = fake_ioctx
+            tpool_mock.return_value = fake_proxy
+            rbd_mock.return_value = fake_rbd
+
+            self.store._delete_image('fake_pool', self.location.image)
+
+            tpool_mock.assert_called_once_with(fake_rbd)
+            fake_proxy.remove.assert_called_once_with(fake_ioctx,
+                                                      self.location.image)
